@@ -186,6 +186,9 @@ class NeoBeeShell:
         """
         Connects to the controller. If a connection already has been
         established, an AlreadyConnectedError is raised.
+
+        The preferred way to use this class is in a `with` statement,
+        which eliminates the need to connect or disconnect explicitly.
         """
         if self.connected:
             raise AlreadyConnectedError()
@@ -229,23 +232,23 @@ class NeoBeeShell:
 
     def _send(self):
         if not self.connected:
-            raise NotConnectedError()
+            raise NotConnectedError("Not connected")
 
         requestcommand = self.command
         try:
             self._socket.send(self._buffer)
             self._receive()
         except:
-            raise NetworkError()
+            raise NetworkError("Network error")
 
         if requestcommand != self.command:
-            raise WrongResponseCommandError()
+            raise WrongResponseCommandError("Response command does not match request command.")
 
         if self.status == StatusCode.BAD_REQUEST:
-            raise BadRequestError()
+            raise BadRequestError("Bad request")
 
         if self.status == StatusCode.BAD_METHOD:
-            raise BadMethodError()
+            raise BadMethodError("Bad method")
 
     def _print_buffer(self):
         print(":".join("{:02x}".format(x) for x in self._buffer))
@@ -258,6 +261,10 @@ class NeoBeeShell:
 
     @property
     def version(self):
+        """
+        Returns the version of the firmware as a tuple
+        (MAJOR, MINOR, BUILD).
+        """
         if not self.connected:
             raise NotConnectedError()
 
@@ -274,6 +281,10 @@ class NeoBeeShell:
 
     @property
     def info(self) -> NeoBeeInfo:
+        """
+        Returns a `NeoBeeInfo` object, which contains all the current
+        settings.
+        """
         if not self.connected:
             raise NotConnectedError()
 
@@ -321,6 +332,9 @@ class NeoBeeShell:
 
     @property
     def scale_offset(self):
+        """
+        Float property for the offset of the scale.
+        """
         if not self.connected:
             raise NotConnectedError()
 
@@ -356,8 +370,11 @@ class NeoBeeShell:
 
     @property
     def scale_factor(self):
+        """
+        Float property for the scale factor.
+        """
         if not self.connected:
-            raise NotConnectedError()
+            raise NotConnectedError("Not connected")
 
         self._clearbuffer()
         self.method = RequestMethod.GET
@@ -373,7 +390,7 @@ class NeoBeeShell:
     @scale_factor.setter
     def scale_factor(self, value: float):
         if not self.connected:
-            raise NotConnectedError()
+            raise NotConnectedError("Not connected")
 
         if value <= 0:
             raise BadRequestError("Factor must be a positive value.")
@@ -390,8 +407,12 @@ class NeoBeeShell:
 
     @property
     def mac_address(self):
+        """
+        Returns a MacAddress object with the mac address
+        of the board.
+        """
         if not self.connected:
-            raise NotConnectedError()
+            raise NotConnectedError("Not connected")
 
         self._clearbuffer()
         self.method = RequestMethod.GET
@@ -404,22 +425,30 @@ class NeoBeeShell:
 
     @property
     def name(self):
+        """
+        String property for the name of the board.
+        The length of the name is limited to 20 and
+        is expected to be in ascii encoded.
+
+        If a name longer then 20 characters is provided,
+        a DataError is raised.
+        """
         if not self.connected:
-            raise NotConnectedError()
+            raise NotConnectedError("Not connected")
 
         self._clearbuffer()
         self.method = RequestMethod.GET
         self.command = CmdCode.NAME
         self._send()
         if self.status == StatusCode.OK:
-            return bytearray(filter(lambda x: x is not 0, self._buffer[2:])).decode("ascii")
+            return bytearray(filter(lambda x: x != 0, self._buffer[2:])).decode("ascii")
         else:
             return None
 
     @name.setter
     def name(self, name: str):
         if not self.connected:
-            raise NotConnectedError()
+            raise NotConnectedError("Not connected")
 
         self._clearbuffer()
         self.method = RequestMethod.PUT
@@ -434,16 +463,23 @@ class NeoBeeShell:
         self._send()
 
     def save_settings(self):
+        """
+        Stores the settings to the flash memory.
+        """
         if not self.connected:
-            raise NotConnectedError()
+            raise NotConnectedError("Not connected")
 
         self._clearbuffer()
         self.command = CmdCode.SAVE_SETTINGS
         self._send()
 
     def erase_settings(self):
+        """
+        Removes the stored settings from flash memory.
+        After a reboot, the board acts as a AP again.
+        """
         if not self.connected:
-            raise NotConnectedError()
+            raise NotConnectedError("Not connected")
 
         self._clearbuffer()
         self.command = CmdCode.ERASE_SETTINGS
@@ -451,7 +487,7 @@ class NeoBeeShell:
 
     def reset_settings(self):
         if not self.connected:
-            raise NotConnectedError()
+            raise NotConnectedError("Not connected")
 
         self._clearbuffer()
         self.command = CmdCode.RESET_SETTINGS
@@ -459,8 +495,11 @@ class NeoBeeShell:
 
     @property
     def ssid(self) -> str:
+        """
+        String property for the ssid of the wifi network.
+        """
         if not self.connected:
-            raise NotConnectedError()
+            raise NotConnectedError("Not connected")
 
         self._clearbuffer()
         self.method = RequestMethod.GET
@@ -474,7 +513,7 @@ class NeoBeeShell:
     @ssid.setter
     def ssid(self, val: str):
         if not self.connected:
-            raise NotConnectedError()
+            raise NotConnectedError("Not connected")
 
         self._clearbuffer()
         self.command = CmdCode.SSID
@@ -488,6 +527,9 @@ class NeoBeeShell:
 
     @property
     def wifi_password(self):
+        """
+        String property for the wifi_password.
+        """
         self._clearbuffer()
         self.method = RequestMethod.GET
         self.command = CmdCode.PASSWORD
@@ -503,7 +545,7 @@ class NeoBeeShell:
     @wifi_password.setter
     def wifi_password(self, password: str):
         if not self.connected:
-            raise NotConnectedError()
+            raise NotConnectedError("Not connected")
 
         self._clearbuffer()
         self.command = CmdCode.PASSWORD
@@ -518,7 +560,7 @@ class NeoBeeShell:
     @property
     def deep_sleep_seconds(self):
         if not self.connected:
-            raise NotConnectedError()
+            raise NotConnectedError("Not connected")
 
         self._clearbuffer()
         self.method = RequestMethod.GET
@@ -529,7 +571,7 @@ class NeoBeeShell:
     @deep_sleep_seconds.setter
     def deep_sleep_seconds(self, val: int):
         if not self.connected:
-            raise NotConnectedError()
+            raise NotConnectedError("Not connected")
 
         self._clearbuffer()
         self.method = RequestMethod.PUT
@@ -541,6 +583,10 @@ class NeoBeeShell:
 
     @property
     def temperature(self):
+        """
+        Reads the temperature of both sensors. Returns the temperature
+        as a float value in celsius degree.
+        """
         self._clearbuffer()
         self.method = RequestMethod.GET
         self.command = CmdCode.GET_TEMPERATURE
@@ -548,6 +594,16 @@ class NeoBeeShell:
         return ((self[0] << 24) | (self[1] << 16) | (self[2] << 8) | self[3]) / 100
 
     def tare(self, nr_times: int):
+        """
+        Command to trigger the taring.
+
+        Taring is the process to determine the 0 value of
+        the scale. So, before triggering this command, empty
+        the scale.
+
+        nr_times specifies the number of measurements excecuted to
+        calculate the tare as an average of the measured values.
+        """
         self._clearbuffer()
         self.method = RequestMethod.NONE
         self.command = CmdCode.TARE
@@ -558,14 +614,28 @@ class NeoBeeShell:
         return (offset, factor)
 
     def calibrate(self, ref_weight: int, count: int):
-        print("Calibrating", count, "-times")
+        """
+        Calibrates the scale. Before calibrating the scale, be sure,
+        to tare the scale correctly.
+
+        To calibrate the weight, a reference weight is needed. And the value
+        you provide determines the unit to be used.
+
+        Example:
+
+        Put a weight of 1 kilogramm onto the scale. If you now call this method
+        with a ref_weight of 1, all measurements are done in kilogramm. If you call
+        this method with a value of 1000, all measurements are done in gramm.
+        """
+        if not self.scale_offset:
+            raise BadRequestError("Scale not tared or not present.")
+
         self._clearbuffer()
         self.method = RequestMethod.GET
         self.command = CmdCode.CALIBRATE
         self[0] = (ref_weight >> 8) & 0xFF
         self[1] = ref_weight & 0xFF
         self[2] = count & 0xFF
-        self._print_buffer()
         self._send()
         offset = ((self[0] << 24) | (self[1] << 16) | (self[2] << 8) | self[3]) / 100
         factor = ((self[4] << 24) | (self[5] << 16) | (self[6] << 8) | self[7]) / 100
